summaryrefslogtreecommitdiffstats
path: root/src/gvcore/externaltoolaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gvcore/externaltoolaction.h')
-rw-r--r--src/gvcore/externaltoolaction.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gvcore/externaltoolaction.h b/src/gvcore/externaltoolaction.h
index 9e5e1ff..711f0c0 100644
--- a/src/gvcore/externaltoolaction.h
+++ b/src/gvcore/externaltoolaction.h
@@ -29,10 +29,10 @@ class KService;
namespace Gwenview {
/**
* A specialized version of KAction, which is aware of the tool to run as well
* as the urls to call it with.
*/
-class ExternalToolAction : public KAction {
+class ExternalToolAction : public TDEAction {
Q_OBJECT
public:
@@ -29,10 +29,10 @@ class KService;
namespace Gwenview {
/**
- * A specialized version of KAction, which is aware of the tool to run as well
+ * A specialized version of TDEAction, which is aware of the tool to run as well
* as the urls to call it with.
*/